Schevo Glossary — libschevo 3.2.4 documentation

### Navigation

- index
- next |
- previous |
- libschevo 3.2.4 documentation »
- Schevo References »

# Schevo Glossary

## database

## database navigator

An application that allows use browsing, searching, and updating any Schevo database without additional GUI code.

Typically, a database navigator makes use of a reusable widget library that allows developers to create custom applications using the same widgets that the database navigator uses.

## data set

## default key

## engine

## entity

An instance of an entity class.

## entity class

## evolve

## execute

## extension method

## extension namespace

## extent

A collection of entities all conforming to the same entity class, along with information reflecting that entity class and the extent’s role as a collection.

An extent has a q namespace, a t namespace, and an x namespace.

## f namespace

Abbreviation for field class namespace (in the case of the f attribute of an extent) or for field namespace (in the case of the f attribute of an entity, transaction, or view).

## field

## field class

## field class namespace

## field namespace

## field value

## index

## index spec

An n-tuple containing the one or more field names that are used in an index maintained for an extent.

## initial data set

A data set that is loaded into an open database when a database is initially created, and that typically contains data required for the database to function properly.

## key

## key spec

An n-tuple containing the one or more field names that are used in a key maintained for an extent.

## label

## OID

An integer object identifier used internally.

## open database

## pack

To reorganize the on-disk representation of a database to reduce memory pressure of open databases and reduce the time it takes to open a database.

## plural label

## q namespace

Abbreviation of query namespace.

## query namespace

## relationship

A 2-tuple containing an entity class name and a field name, where a field value for that field on an entity of that type may refer to entities in a particular extent.

## sample data set

A data set that is loaded into an open database upon request, and that typically contains sample data used for testing or demonstration purposes.

## schema

## schema body

## schema package

## schema source

## schema version

The current version of the schema source used by a database.

A database begins at version `0`, when it does not yet have a schema associated with it.

Once the engine successfully processes the first version of the schema, it sets the database version to `1`.

Once the engine successfully evolves a database to a succeeding version of the schema, it increments the database version accordingly.

## storage backend

## t namespace

Abbreviation of transaction namespace.

## transaction

## transaction method

A method attached to a database, extent, entity, or view that returns a transaction when called.

Transaction methods, to facilitate dynamic usage, must not require any arguments. They may accept arguments to facilitate programmatic usage.

## transaction namespace

## v namespace

Abbreviation of view namespace.

## view

## view method

## view namespace

## x namespace

Abbreviation of extension namespace.

### Navigation

- index
- next |
- previous |
- libschevo 3.2.4 documentation »
- Schevo References »